package com.tasktop.c2c.server.scm.domain;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * Represents access right objects to repository branch.
 * 
 * @author Pavel Flaska
 */
@SuppressWarnings("serial")
public final class BranchAccessConfig implements Serializable {

    public static final int PROTECTED = 0x1;
    public static final int RESTRICTED = PROTECTED << 1;
    public static final int FORCE_FORBIDDEN = RESTRICTED << 1;

    private String repository;
    private String branch;
    private Integer state;
    private List<String> users;

    public BranchAccessConfig() {
        this.users = new ArrayList<String>();
        this.branch = "";
        this.state = 0x0;
    }
    
    public String getRepository() {
        return repository;
    }

    public void setRepository(String repository) {
        this.repository = repository;
    }

    public int getState() {
        return state;
    }

    public void setState(int state) {
        this.state = state;
    }
    
    public boolean contains(String user) {
        return users.contains(user);
    }

    public String getBranch() {
        return branch;
    }

    public void setBranch(String branch) {
        this.branch = branch;
    }
    
    public String[] getUsers() {
        return users.toArray(new String[0]);
    }
    
    public void setUsers(String[] users) {
        assert users != null: "Null is not allowed.";
        this.users = Arrays.asList(users);
    }
    
}
