/*
 * Copyright (c) 2014 phrebejk.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    phrebejk - initial API and implementation and/or initial documentation
 */

package com.tasktop.c2c.server.scm.domain;

import java.io.Serializable;

/** Request and Status for importing a repository.
 *
 * @author phrebejk
 */
public class Import implements Serializable{
    
    private static final long serialVersionUID = 1L;

    public Import() {

    }

    public static class Status implements Serializable {

        public enum State {
            UNKNOWN,            // Nothing known about this repo
            IMPORTING,          // Import in progress
            FINISHED,           // Import finished
            NOT_AVAILABLE,      // URL of the repo is not a git repo
            NEEDS_CREDENTIALS,  // No credentials specified but password protected
            ERROR;              // Other error
        }

        public final String url;
        
        public final String taskName;

        public final int workCurr;

        public final int workTotal;

        public final int percentDone;

        public final State state;

        public Status( String url, State state ) {
            this.url = url;            
            this.taskName = null;
            this.workCurr = -1;
            this.workTotal = -1;
            this.percentDone = -1;
            this.state = state;
        }

        public Status(String url, String taskName, int workCurr, int workTotal, int percentDone) {
            this.url = url;            
            this.taskName = taskName;
            this.workCurr = workCurr;
            this.workTotal = workTotal;
            this.percentDone = percentDone;
            this.state = State.IMPORTING;
        }

    }

    public static class Request {

        private String url;

        private String username;

        private String password;

        private boolean dryRun;

        public String getUrl() {
            return url;
        }

        public void setUrl(String url) {
            this.url = url;
        }

        public String getUsername() {
            return username;
        }

        public void setUsername(String username) {
            this.username = username;
        }

        public String getPassword() {
            return password;
        }

        public void setPassword(String password) {
            this.password = password;
        }

        public boolean isDryRun() {
            return dryRun;
        }

        public void setDryRun(boolean dryRun) {
            this.dryRun = dryRun;
        }
        
    }

}
